@@ -1,4 +1,15 @@
-//@line 39 "/home/karma/src/build/toolkit/content/nsDragAndDrop.js"
+//@line 39 "/home/karma/src/build/build/toolkit/content/nsDragAndDrop.js"
+
+////////////////////////////////////////////////////////////////////////
+//
+// USE OF THIS API FOR DRAG AND DROP IS DEPRECATED!
+// Do not use this file for new code.
+//
+// For documentation about what to use instead, see:
+//   http://developer.mozilla.org/En/DragDrop/Drag_and_Drop
+//
+////////////////////////////////////////////////////////////////////////
+
 
 /** 
  *  nsTransferable - a wrapper for nsITransferable that simplifies
@@ -537,6 +548,13 @@ var nsDragAndDrop = {
    **/
   dragDropSecurityCheck: function (aEvent, aDragSession, aDraggedText)
     {
+      if (!aDragSession)
+        aDragSession = this.mDragService.getCurrentSession();
+
+      var sourceDoc = aDragSession.sourceDocument;
+      if (!sourceDoc)
+        return;
+
       // Strip leading and trailing whitespace, then try to create a
       // URI from the dropped string. If that succeeds, we're
       // dropping a URI and we need to do a security check to make
@@ -565,11 +583,8 @@ var nsDragAndDrop = {
       var secMan = Components.classes["@mozilla.org/scriptsecuritymanager;1"]
                              .getService(nsIScriptSecurityManager);
 
-      var sourceDoc = aDragSession.sourceDocument;
-      var sourceURI = sourceDoc ? sourceDoc.documentURI : "file:///";
-
       try {
-        secMan.checkLoadURIStr(sourceURI, aDraggedText,
+        secMan.checkLoadURIStr(sourceDoc.documentURI, aDraggedText,
                                nsIScriptSecurityManager.STANDARD);
       } catch (e) {
         // Stop event propagation right here.
